@@ -1,3 +1,6 @@
+from bg4h.helpers import DeprecatedAttr
+
+
 class BgMain: 
 
     class RecOperaciones:
@@ -152,6 +155,7 @@ class BgMain:
         currency = 'TCOSTEPRECIOHORACATPROF9'
   
     class DatosDeControl :
+        article_tax_code = DeprecatedAttr("TDATOSDECONTROL40","article_tax_code", "default_article_tax_code")
         _tbl = 'TDATOSDECONTROL'
         code = 'TDATOSDECONTROL1'
         name = 'TDATOSDECONTROL2'
@@ -425,6 +429,25 @@ class BgMain:
         days = 'TVACACIONES5'
         index = 'TVACACIONES6'
   
+    class OtrosVacaciones:
+        _tbl = 'TOTROSVACACIONES'
+        date = 'TOTROSVACACIONES1'
+        days = 'TOTROSVACACIONES2'
+        type = 'TOTROSVACACIONES3'
+        hours = 'TOTROSVACACIONES4'
+        observations = 'TOTROSVACACIONES5'
+        worker = 'TOTROSVACACIONES6'
+
+    class OtrasIncidenciasPersonal:
+        _tbl  = 'TOTRASINCIDENCIASPERSONAL'
+        code = 'TOTRASINCIDENCIASPERSONAL1'
+        desc = 'TOTRASINCIDENCIASPERSONAL2'
+        reason = 'TOTRASINCIDENCIASPERSONAL3'
+
+
+
+
+
     class Vencimientos:
         _tbl = 'TVENCIMIENTOS'
         days = 'TVENCIMIENTOS2'
